package Perl::Achievements::Role::ConfigItem;
BEGIN {
  $Perl::Achievements::Role::ConfigItem::AUTHORITY = 'cpan:YANICK';
}
{
  $Perl::Achievements::Role::ConfigItem::VERSION = '0.1.0';
}

use strict;
use warnings;

use Moose::Role;


1;




__END__
=pod

=head1 NAME

Perl::Achievements::Role::ConfigItem

=head1 VERSION

version 0.1.0

=head1 AUTHOR

Yanick Champoux <yanick@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2012 by Yanick Champoux.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

